"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const dictionary_1 = require("./dictionary");
const optional_1 = require("../optional");
(0, vitest_1.describe)("Dictionary Tests", () => {
    (0, vitest_1.test)("置いたものを取り出せる", () => {
        let dictionary = (0, dictionary_1.dict)();
        dictionary = dictionary.put("a", 1);
        (0, vitest_1.expect)(dictionary.get("a")).toEqual((0, optional_1.some)(1));
    });
    (0, vitest_1.test)("値を更新できる", () => {
        let dictionary = (0, dictionary_1.dict)({
            hello: "world",
        });
        dictionary = dictionary.put("hello", "こんにちは");
        (0, vitest_1.expect)(dictionary.get("hello")).toEqual((0, optional_1.some)("こんにちは"));
    });
    (0, vitest_1.test)("nullまたはnoneまたはundefinedで更新すると消せる", () => {
        let dictionary = (0, dictionary_1.dict)({
            hello: "world",
        });
        const nullDictionary = dictionary.put("hello", null);
        (0, vitest_1.expect)(nullDictionary.get("hello")).toBe((0, optional_1.none)());
        const undefinedDictionary = dictionary.put("hello", undefined);
        (0, vitest_1.expect)(undefinedDictionary.get("hello")).toBe((0, optional_1.none)());
        const noneDictionary = dictionary.put("hello", (0, optional_1.none)());
        (0, vitest_1.expect)(noneDictionary.get("hello")).toBe((0, optional_1.none)());
    });
    (0, vitest_1.test)("decodable", () => {
        const json = {
            hello: true,
            world: false,
        };
        const origin = (0, dictionary_1.dict)([(0, dictionary_1.kv)("", true)]);
        const actual = origin.decode(json);
        (0, vitest_1.expect)(actual.get("hello")).toEqual((0, optional_1.some)(true));
        (0, vitest_1.expect)(actual.get("world")).toEqual((0, optional_1.some)(false));
    });
});
//# sourceMappingURL=dictionary.test.js.map